==> appfy-0.0.4.tgz: package/appfy.js <==
/**
 * Appfy provides a modular workflow to scaffold and build web applications
 * 
 * Software licensed under MIT, maintained by @stewones. Feel free to open an issue or make a PR.
 * Check out documentation and full list of contributors in http://appfy.ninja
 *
 * Copyright © 2014 Stewan Pacheco <talk@stpa.co>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the “Software”), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 **/

'use strict';

//load dep
var _ = require('lodash'),
    program = require('commander'),
    gulp = require('gulp'),
    gulpif = require('gulp-if'),
    install = require('gulp-install'),
    conflict = require('gulp-conflict'),
    template = require('gulp-template'),
    rename = require('gulp-rename'),
    inquirer = require('inquirer'),
    colors = require('colors'),
    gutil = require('gulp-util'),
    exec = require('gulp-exec'),
    nodemon = require('nodemon'),
    fs = require('fs'),
    path = require('path');

//load gen
require('./generator/application')(_, gulp, gulpif, install, conflict, template, rename, inquirer, colors, path, injectAngularModules);
require('./generator/client.module')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path, injectAngularModules);
require('./generator/client.controller')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.component')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.directive')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.filter')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.service')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.factory')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.serve')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/serve')(_, gulp, gutil, nodemon);
require('./generator/api.serve')(_, gulp, gutil, nodemon);
require('./generator/api.endpoint')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path, injectApiRoutes);

//load app config
try {
    var appfy = require(process.cwd() + '/appfy.json');
    if (appfy) {
        appfy = appfy.application.setting || false;
    } else {
        appfy = {};
    }
}
catch (e) {
    var appfy = {};
    //console.log(e);
}


//cli    
program
    .version('0.0.1');

//create app
program
    .command('new')
    .arguments('<app_name>')
    .description('create new application')
    .action(function (app_name) {
        var dir = './' + app_name;
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
        }
        try {
            process.chdir(dir);
            process.env.app_name = app_name;
            gulp.start('new');
        }
        catch (err) {
            console.log(`chdir: ${err}`);
        }
    });

//parse
program.parse(process.argv);




function getDirectories(srcpath) {
    try {
        var files = fs.readdirSync(srcpath);
        if (files.length) {
            return files.filter(function (file) {
                return fs.statSync(path.join(srcpath, file)).isDirectory();
            });
        } else {
            return [];
        }
    } catch ($e) {
        return [];
        //   console.log($e)
    }
}

function injectAngularModules(appName) {
    var answers = {};
    var modules = getDirectories(process.cwd() + '/client/src/app/modules');

    answers.modules = modules || [];
    answers.name = appName || appfy.name || 'appfy';
    var inject = [__dirname + '/template/application/client/src/app/app.module.js']; // Note use of __dirname to be relative to generator
    return gulp.src(inject)
        .pipe(template(answers)) // Lodash template support 
        .pipe(conflict('./client/src/app')) // Confirms overwrites on file conflicts
        .pipe(gulp.dest('./client/src/app')); // Without __dirname here = relative to cwd 
}


function injectApiRoutes(appName) {
    var answers = {};
    var modules = getDirectories(process.cwd() + '/server/api');
    answers.modules = modules || [];
    var inject = [__dirname + '/template/application/server/routes.js']; // Note use of __dirname to be relative to generator
    return gulp.src(inject)
        .pipe(template(answers)) // Lodash template support 
        .pipe(conflict('./server')) // Confirms overwrites on file conflicts
        .pipe(gulp.dest('./server')) // Without __dirname here = relative to cwd 
        ;
}

==> appfy-0.0.5.tgz: package/appfy.js <==
/**
 * Appfy provides a modular workflow to scaffold and build web applications
 * 
 * Software licensed under MIT, maintained by @stewones. Feel free to open an issue or make a PR.
 * Check out documentation and full list of contributors in http://appfy.ninja
 *
 * Copyright © 2014 Stewan Pacheco <talk@stpa.co>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the “Software”), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 **/

'use strict';

//load dep
var VERSION = '0.0.5',
    _ = require('lodash'),
    program = require('commander'),
    gulp = require('gulp'),
    gulpif = require('gulp-if'),
    install = require('gulp-install'),
    conflict = require('gulp-conflict'),
    template = require('gulp-template'),
    rename = require('gulp-rename'),
    inquirer = require('inquirer'),
    colors = require('colors'),
    gutil = require('gulp-util'),
    exec = require('gulp-exec'),
    nodemon = require('nodemon'),
    fs = require('fs'),
    path = require('path');

//load gen
require('./generator/application')(_, gulp, gulpif, install, conflict, template, rename, inquirer, colors, path, injectAngularModules);
require('./generator/client.module')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path, injectAngularModules);
require('./generator/client.controller')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.component')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.directive')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.filter')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.service')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.factory')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/client.serve')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path);
require('./generator/serve')(_, gulp, gutil, nodemon);
require('./generator/api.serve')(_, gulp, gutil, nodemon);
require('./generator/api.endpoint')(_, gulp, install, conflict, template, rename, inquirer, colors, gutil, exec, fs, path, injectApiRoutes);

//load app config
try {
    var appfy = require(process.cwd() + '/appfy.json');
    if (appfy) {
        appfy = appfy.application.setting || false;
    } else {
        appfy = {};
    }
}
catch (e) {
    var appfy = {};
    //console.log(e);
}


//cli    
program
    .version(VERSION);

//create app
program
    .command('new')
    .arguments('<app_name>')
    .description('create new application')
    .action(function (app_name) {
        var dir = './' + app_name;
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
        }
        try {
            process.chdir(dir);
            process.env.app_name = app_name;
            gulp.start('new');
        }
        catch (err) {
            console.log(`chdir: ${err}`);
        }
    });

//parse
program.parse(process.argv);




function getDirectories(srcpath) {
    try {
        var files = fs.readdirSync(srcpath);
        if (files.length) {
            return files.filter(function (file) {
                return fs.statSync(path.join(srcpath, file)).isDirectory();
            });
        } else {
            return [];
        }
    } catch ($e) {
        return [];
        //   console.log($e)
    }
}

function injectAngularModules(appName) {
    var answers = {};
    var modules = getDirectories(process.cwd() + '/client/src/app/modules');

    answers.modules = modules || [];
    answers.name = appName || appfy.name || 'appfy';
    var inject = [__dirname + '/template/application/client/src/app/app.module.js']; // Note use of __dirname to be relative to generator
    return gulp.src(inject)
        .pipe(template(answers)) // Lodash template support 
        .pipe(conflict('./client/src/app')) // Confirms overwrites on file conflicts
        .pipe(gulp.dest('./client/src/app')); // Without __dirname here = relative to cwd 
}


function injectApiRoutes(appName) {
    var answers = {};
    var modules = getDirectories(process.cwd() + '/server/api');
    answers.modules = modules || [];
    var inject = [__dirname + '/template/application/server/routes.js']; // Note use of __dirname to be relative to generator
    return gulp.src(inject)
        .pipe(template(answers)) // Lodash template support 
        .pipe(conflict('./server')) // Confirms overwrites on file conflicts
        .pipe(gulp.dest('./server')) // Without __dirname here = relative to cwd 
        ;
}
